@@ -5,19 +5,19 @@ from .normalized_kernel import NormalizedKernel
 class MultivariateNormalKernel(NormalizedKernel):
     """ Multivariate normal kernel """
 
-    def __init__(self, mu, scale_tril):
-        self.set_density(mu, scale_tril)
+    def __init__(self, loc, scale_tril):
+        self.set_density(loc, scale_tril)
 
-    def set_density(self, mu, scale_tril):
+    def set_density(self, loc, scale_tril):
         """ Set multivariate normal probability density function """
-        self.density = MultivariateNormal(mu, scale_tril=scale_tril)
+        self.density = MultivariateNormal(loc, scale_tril=scale_tril)
 
-    def set_density_params(self, mu, scale_tril=None):
+    def set_density_params(self, loc, scale_tril=None):
         """ Set the parameters of multivariate normal probability density function """
-        self.density.loc = mu
+        self.density.loc = loc
         if scale_tril is not None:
             self.density.scale_tril = scale_tril
 
-    def k(self, x1, x2, sigma=None):
-        self.set_density_params(x2, sigma=sigma)
-        return self.log_density(x1).exp()
+    def k(self, x1, x2, scale=None):
+        self.set_density_params(x2, scale=scale)
+        return self.log_prob(x1).exp()
