@@ -11,7 +11,7 @@ class NormalizedKernel(Kernel):
     def set_density(self):
         raise NotImplementedError
 
-    def log_density(self, state):
+    def log_prob(self, state):
         return torch.sum(self.density.log_prob(state))
 
     def sample(self):
